==> HTTPolice-0.1.0-py2.py3-none-any.whl: httpolice/known/relation_type.py <==
# -*- coding: utf-8; -*-

from httpolice.citation import Citation, RFC
from httpolice.known.base import KnownDict
from httpolice.structure import RelationType


known = KnownDict([
 {'_': RelationType(u'about'), '_citations': [RFC(6903, section=(2,))]},
 {'_': RelationType(u'alternate'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-alternate')]},
 {'_': RelationType(u'appendix'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'archives'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/2011/'
                          u'WD-html5-20110113/links.html#rel-archives')]},
 {'_': RelationType(u'author'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-author')]},
 {'_': RelationType(u'blocked-by'), '_citations': [RFC(7725)]},
 {'_': RelationType(u'bookmark'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-bookmark')]},
 {'_': RelationType(u'canonical'), '_citations': [RFC(6596)]},
 {'_': RelationType(u'chapter'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'collection'), '_citations': [RFC(6573)]},
 {'_': RelationType(u'contents'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'copyright'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'create-form'), '_citations': [RFC(6861)]},
 {'_': RelationType(u'current'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'derivedfrom'), '_citations': []},
 {'_': RelationType(u'describedby'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/powder-dr/#assoc-linking')]},
 {'_': RelationType(u'describes'), '_citations': [RFC(6892)]},
 {'_': RelationType(u'disclosure'), '_citations': [RFC(6579)]},
 {'_': RelationType(u'dns-prefetch'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'duplicate'), '_citations': [RFC(6249)]},
 {'_': RelationType(u'edit'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'edit-form'), '_citations': [RFC(6861)]},
 {'_': RelationType(u'edit-media'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'enclosure'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'first'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'glossary'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'help'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-help')]},
 {'_': RelationType(u'hosts'), '_citations': [RFC(6690)]},
 {'_': RelationType(u'hub'),
  '_citations': [Citation(None, 'http://pubsubhubbub.googlecode.com')]},
 {'_': RelationType(u'icon'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-icon')]},
 {'_': RelationType(u'index'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'item'), '_citations': [RFC(6573)]},
 {'_': RelationType(u'last'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'latest-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'license'), '_citations': [RFC(4946)]},
 {'_': RelationType(u'lrdd'), '_citations': [RFC(6415)]},
 {'_': RelationType(u'memento'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'monitor'), '_citations': [RFC(5989)]},
 {'_': RelationType(u'monitor-group'), '_citations': [RFC(5989)]},
 {'_': RelationType(u'next'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-next')]},
 {'_': RelationType(u'next-archive'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'nofollow'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-nofollow')]},
 {'_': RelationType(u'noreferrer'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-noreferrer')]},
 {'_': RelationType(u'original'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'payment'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'pingback'),
  '_citations': [Citation(None,
                          u'http://www.hixie.ch/specs/pingback/pingback')]},
 {'_': RelationType(u'preconnect'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'predecessor-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'prefetch'),
  '_citations': [Citation(None, 'http://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'preload'),
  '_citations': [Citation(None, 'http://www.w3.org/TR/preload/')]},
 {'_': RelationType(u'prerender'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'prev'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-prev')]},
 {'_': RelationType(u'preview'), '_citations': [RFC(6903, section=(3,))]},
 {'_': RelationType(u'previous'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'prev-archive'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'privacy-policy'),
  '_citations': [RFC(6903, section=(4,))]},
 {'_': RelationType(u'profile'), '_citations': [RFC(6906)]},
 {'_': RelationType(u'related'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'replies'), '_citations': [RFC(4685)]},
 {'_': RelationType(u'search'),
  '_citations': [Citation(None,
                          u'http://www.opensearch.org/Specifications/'
                          u'OpenSearch/1.1')]},
 {'_': RelationType(u'section'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'self'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'service'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'start'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'stylesheet'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-stylesheet')]},
 {'_': RelationType(u'subsection'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'successor-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'tag'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-tag')]},
 {'_': RelationType(u'terms-of-service'),
  '_citations': [RFC(6903, section=(5,))]},
 {'_': RelationType(u'timegate'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'timemap'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'type'), '_citations': [RFC(6903, section=(6,))]},
 {'_': RelationType(u'up'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'version-history'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'via'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'webmention'),
  '_citations': [Citation(None, u'http://www.w3.org/TR/webmention/')]},
 {'_': RelationType(u'working-copy'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'working-copy-of'), '_citations': [RFC(5829)]},
 ])

==> HTTPolice-0.3.0-py2.py3-none-any.whl: httpolice/known/relation_type.py <==
# -*- coding: utf-8; -*-

from httpolice.citation import RFC, Citation
from httpolice.known.base import KnownDict
from httpolice.structure import RelationType


known = KnownDict(RelationType, [
 {'_': RelationType(u'about'), '_citations': [RFC(6903, section=(2,))]},
 {'_': RelationType(u'alternate'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-alternate')]},
 {'_': RelationType(u'appendix'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'archives'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/2011/'
                          u'WD-html5-20110113/links.html#rel-archives')]},
 {'_': RelationType(u'author'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-author')]},
 {'_': RelationType(u'blocked-by'), '_citations': [RFC(7725, section=(4,))]},
 {'_': RelationType(u'bookmark'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-bookmark')]},
 {'_': RelationType(u'canonical'), '_citations': [RFC(6596)]},
 {'_': RelationType(u'chapter'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'collection'), '_citations': [RFC(6573)]},
 {'_': RelationType(u'contents'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'copyright'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'create-form'), '_citations': [RFC(6861)]},
 {'_': RelationType(u'current'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'derivedfrom'), '_citations': []},
 {'_': RelationType(u'describedby'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/powder-dr/#assoc-linking')]},
 {'_': RelationType(u'describes'), '_citations': [RFC(6892)]},
 {'_': RelationType(u'disclosure'), '_citations': [RFC(6579)]},
 {'_': RelationType(u'dns-prefetch'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'duplicate'), '_citations': [RFC(6249)]},
 {'_': RelationType(u'edit'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'edit-form'), '_citations': [RFC(6861)]},
 {'_': RelationType(u'edit-media'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'enclosure'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'first'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'glossary'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'help'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-help')]},
 {'_': RelationType(u'hosts'), '_citations': [RFC(6690)]},
 {'_': RelationType(u'hub'),
  '_citations': [Citation(None, 'http://pubsubhubbub.googlecode.com')]},
 {'_': RelationType(u'icon'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-icon')]},
 {'_': RelationType(u'index'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'item'), '_citations': [RFC(6573)]},
 {'_': RelationType(u'last'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'latest-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'license'), '_citations': [RFC(4946)]},
 {'_': RelationType(u'lrdd'), '_citations': [RFC(6415)]},
 {'_': RelationType(u'memento'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'monitor'), '_citations': [RFC(5989)]},
 {'_': RelationType(u'monitor-group'), '_citations': [RFC(5989)]},
 {'_': RelationType(u'next'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-next')]},
 {'_': RelationType(u'next-archive'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'nofollow'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-nofollow')]},
 {'_': RelationType(u'noreferrer'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-noreferrer')]},
 {'_': RelationType(u'original'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'payment'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'pingback'),
  '_citations': [Citation(None,
                          u'http://www.hixie.ch/specs/pingback/pingback')]},
 {'_': RelationType(u'preconnect'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'predecessor-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'prefetch'),
  '_citations': [Citation(None, 'http://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'preload'),
  '_citations': [Citation(None, 'http://www.w3.org/TR/preload/')]},
 {'_': RelationType(u'prerender'),
  '_citations': [Citation(None, 'https://www.w3.org/TR/resource-hints/')]},
 {'_': RelationType(u'prev'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-prev')]},
 {'_': RelationType(u'preview'), '_citations': [RFC(6903, section=(3,))]},
 {'_': RelationType(u'previous'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'prev-archive'), '_citations': [RFC(5005)]},
 {'_': RelationType(u'privacy-policy'),
  '_citations': [RFC(6903, section=(4,))]},
 {'_': RelationType(u'profile'), '_citations': [RFC(6906)]},
 {'_': RelationType(u'related'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'replies'), '_citations': [RFC(4685)]},
 {'_': RelationType(u'search'),
  '_citations': [Citation(None,
                          u'http://www.opensearch.org/Specifications/'
                          u'OpenSearch/1.1')]},
 {'_': RelationType(u'section'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'self'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'service'), '_citations': [RFC(5023)]},
 {'_': RelationType(u'start'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'stylesheet'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-stylesheet')]},
 {'_': RelationType(u'subsection'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/1999/REC-html401-19991224')]},
 {'_': RelationType(u'successor-version'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'tag'),
  '_citations': [Citation(None,
                          u'http://www.w3.org/TR/html5/links.html'
                          u'#link-type-tag')]},
 {'_': RelationType(u'terms-of-service'),
  '_citations': [RFC(6903, section=(5,))]},
 {'_': RelationType(u'timegate'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'timemap'), '_citations': [RFC(7089)]},
 {'_': RelationType(u'type'), '_citations': [RFC(6903, section=(6,))]},
 {'_': RelationType(u'up'), '_citations': [RFC(5988)]},
 {'_': RelationType(u'version-history'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'via'), '_citations': [RFC(4287)]},
 {'_': RelationType(u'webmention'),
  '_citations': [Citation(None, u'http://www.w3.org/TR/webmention/')]},
 {'_': RelationType(u'working-copy'), '_citations': [RFC(5829)]},
 {'_': RelationType(u'working-copy-of'), '_citations': [RFC(5829)]},
 ])
